@@ -9,7 +9,7 @@ from hashlib import md5, sha256
 from msmart.const import MSGTYPE_ENCRYPTED_REQUEST, MSGTYPE_ENCRYPTED_RESPONSE
 from urllib.parse import urlparse
 
-VERSION = '0.1.36'
+VERSION = '0.2.0'
 _LOGGER = logging.getLogger(__name__)
 appKey = '434a209a5ce141c3b726de067835d7f0'
 signKey = 'xhdiwjnchekd4d512chdjx5d8e4c394D2D7S'
@@ -110,6 +110,9 @@ class security:
                 data += get_random_bytes(padding)
         header += size.to_bytes(2, 'big')
         header += bytes([0x20, padding << 4 | msgtype])
+        if self._request_count >= 0xfff:
+            _LOGGER.info("request_count is too big to convert: {}".format(self._request_count))
+            self._request_count = 0 
         data = self._request_count.to_bytes(2, 'big') + data
         self._request_count += 1
         if msgtype in (MSGTYPE_ENCRYPTED_RESPONSE, MSGTYPE_ENCRYPTED_REQUEST):
